==> ace_5.6.3.orig.tar.gz: ACE_wrappers/TAO/tests/OctetSeq/server.cpp <==
// $Id: server.cpp 78998 2007-07-23 12:34:13Z sma $

#include "ace/Get_Opt.h"
#include "test_i.h"
#include "ace/OS_NS_stdio.h"
#include "ace/OS_NS_unistd.h"

ACE_RCSID (OctetSeq,
           server,
           "$Id: server.cpp 78998 2007-07-23 12:34:13Z sma $")

const char *ior_output_file = "test.ior";

int
parse_args (int argc, char *argv[])
{
  ACE_Get_Opt get_opts (argc, argv, "o:");
  int c;

  while ((c = get_opts ()) != -1)
    switch (c)
      {
      case 'o':
        ior_output_file = get_opts.opt_arg ();
        break;
      case '?':
      default:
        ACE_ERROR_RETURN ((LM_ERROR,
                           "usage:  %s "
                           "-o <iorfile>"
                           "\n",
                           argv [0]),
                          -1);
      }
  // Indicates sucessful parsing of the command line
  return 0;
}

int
ACE_TMAIN(int argc, ACE_TCHAR *argv[])
{
  try
    {
      CORBA::ORB_var orb =
        CORBA::ORB_init (argc, argv);

      CORBA::Object_var poa_object =
        orb->resolve_initial_references("RootPOA");

      if (CORBA::is_nil (poa_object.in ()))
        ACE_ERROR_RETURN ((LM_ERROR,
                           " (%P|%t) Unable to initialize the POA.\n"),
                          1);

      PortableServer::POA_var root_poa =
        PortableServer::POA::_narrow (poa_object.in ());

      PortableServer::POAManager_var poa_manager =
        root_poa->the_POAManager ();

      if (parse_args (argc, argv) != 0)
        return 1;

      {
        Database_i server_impl (orb.in (),
                                128); // @@ TODO

        PortableServer::ObjectId_var id =
          root_poa->activate_object (&server_impl);

        CORBA::Object_var object = root_poa->id_to_reference (id.in ());

        Test::Database_var server =
          Test::Database::_narrow (object.in ());

        CORBA::String_var ior =
          orb->object_to_string (server.in ());

        ACE_DEBUG ((LM_DEBUG, "Activated as <%s>\n", ior.in ()));

        // If the ior_output_file exists, output the ior to it
        if (ior_output_file != 0)
          {
            FILE *output_file= ACE_OS::fopen (ior_output_file, "w");
            if (output_file == 0)
              ACE_ERROR_RETURN ((LM_ERROR,
                                 "Cannot open output file for writing IOR: %s",
                                 ior_output_file),
                                1);
            ACE_OS::fprintf (output_file, "%s", ior.in ());
            ACE_OS::fclose (output_file);
          }

        poa_manager->activate ();

        orb->run ();

        ACE_DEBUG ((LM_DEBUG, "event loop finished\n"));
        ACE_OS::sleep(1);
        root_poa->destroy (1, 1);
      }
      ACE_OS::sleep(1);
      orb->destroy ();
    }
  catch (const CORBA::Exception& ex)
    {
      ex._tao_print_exception ("Caught exception:");
      return 1;
    }

  return 0;
}

==> ace_5.7.7.orig.tar.gz: ACE_wrappers/TAO/tests/OctetSeq/server.cpp <==
// $Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $

#include "ace/Get_Opt.h"
#include "test_i.h"
#include "ace/OS_NS_stdio.h"
#include "ace/OS_NS_unistd.h"

ACE_RCSID (OctetSeq,
           server,
           "$Id: server.cpp 83136 2008-10-12 18:07:40Z johnnyw $")

const ACE_TCHAR *ior_output_file = ACE_TEXT("test.ior");

int
parse_args (int argc, ACE_TCHAR *argv[])
{
  ACE_Get_Opt get_opts (argc, argv, ACE_TEXT("o:"));
  int c;

  while ((c = get_opts ()) != -1)
    switch (c)
      {
      case 'o':
        ior_output_file = get_opts.opt_arg ();
        break;
      case '?':
      default:
        ACE_ERROR_RETURN ((LM_ERROR,
                           "usage:  %s "
                           "-o <iorfile>"
                           "\n",
                           argv [0]),
                          -1);
      }
  // Indicates sucessful parsing of the command line
  return 0;
}

int
ACE_TMAIN(int argc, ACE_TCHAR *argv[])
{
  try
    {
      CORBA::ORB_var orb =
        CORBA::ORB_init (argc, argv);

      CORBA::Object_var poa_object =
        orb->resolve_initial_references("RootPOA");

      if (CORBA::is_nil (poa_object.in ()))
        ACE_ERROR_RETURN ((LM_ERROR,
                           " (%P|%t) Unable to initialize the POA.\n"),
                          1);

      PortableServer::POA_var root_poa =
        PortableServer::POA::_narrow (poa_object.in ());

      PortableServer::POAManager_var poa_manager =
        root_poa->the_POAManager ();

      if (parse_args (argc, argv) != 0)
        return 1;

      {
        Database_i server_impl (orb.in (),
                                128); // @@ TODO

        PortableServer::ObjectId_var id =
          root_poa->activate_object (&server_impl);

        CORBA::Object_var object = root_poa->id_to_reference (id.in ());

        Test::Database_var server =
          Test::Database::_narrow (object.in ());

        CORBA::String_var ior =
          orb->object_to_string (server.in ());

        ACE_DEBUG ((LM_DEBUG, "Activated as <%C>\n", ior.in ()));

        // If the ior_output_file exists, output the ior to it
        if (ior_output_file != 0)
          {
            FILE *output_file= ACE_OS::fopen (ior_output_file, "w");
            if (output_file == 0)
              ACE_ERROR_RETURN ((LM_ERROR,
                                 "Cannot open output file for writing IOR: %s",
                                 ior_output_file),
                                1);
            ACE_OS::fprintf (output_file, "%s", ior.in ());
            ACE_OS::fclose (output_file);
          }

        poa_manager->activate ();

        orb->run ();

        ACE_DEBUG ((LM_DEBUG, "event loop finished\n"));
        ACE_OS::sleep(1);
        root_poa->destroy (1, 1);
      }
      ACE_OS::sleep(1);
      orb->destroy ();
    }
  catch (const CORBA::Exception& ex)
    {
      ex._tao_print_exception ("Caught exception:");
      return 1;
    }

  return 0;
}
